# Check Alignments

```
edictor server
```

- click OPEN A DEMO
- go to ADD COLUMN and type COGID and press ENTER
- go to ADD COLUMN and type ALIGNMENT and press ENTER
- go to SETTINGS and make sure *Cognate IDs* has COGID and *Alignment* has ALIGNMENT and press REFRESH SETTINGs
- go to COMPUTE -> COGNATE SETS
- press SUBMIT
- do a right mouse click in one of the fields of the column COGID
- click on EDIT ALIGNMENT
- edit the alignment by clicking on sounds or gaps
- click on SUBMIT

This procedure should run without throwing any errors.
